@@ -16,20 +16,16 @@ static void
 demo_run_navigation_cb (AdwDemoPageSplitViews *self)
 {
   AdwNavigationSplitViewDemoWindow *window = adw_navigation_split_view_demo_window_new ();
-  GtkRoot *root = gtk_widget_get_root (GTK_WIDGET (self));
 
-  gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (root));
-  gtk_window_present (GTK_WINDOW (window));
+  adw_dialog_present (ADW_DIALOG (window), GTK_WIDGET (self));
 }
 
 static void
 demo_run_overlay_cb (AdwDemoPageSplitViews *self)
 {
   AdwOverlaySplitViewDemoWindow *window = adw_overlay_split_view_demo_window_new ();
-  GtkRoot *root = gtk_widget_get_root (GTK_WIDGET (self));
 
-  gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (root));
-  gtk_window_present (GTK_WINDOW (window));
+  adw_dialog_present (ADW_DIALOG (window), GTK_WIDGET (self));
 }
 
 static void
