@@ -1783,11 +1783,11 @@ adw_alert_dialog_add_responses (AdwAlertDialog *self,
 
   g_return_if_fail (ADW_IS_ALERT_DIALOG (self));
 
-  va_start (args, first_id);
-
   if (!first_id)
     return;
 
+  va_start (args, first_id);
+
   id = first_id;
   label = va_arg (args, const char *);
 
@@ -1834,7 +1834,7 @@ adw_alert_dialog_remove_response (AdwAlertDialog *self,
   }
 
   if (priv->default_response == info->id)
-    gtk_window_set_default_widget (GTK_WINDOW (self), NULL);
+    adw_dialog_set_default_widget (ADW_DIALOG (self), NULL);
 
   gtk_widget_unparent (info->button);
 
@@ -2246,7 +2246,7 @@ choose_cancelled_cb (GCancellable *cancellable,
  * @parent: (nullable): the parent widget
  * @cancellable: (nullable): a `GCancellable` to cancel the operation
  * @callback: (scope async): a callback to call when the operation is complete
- * @user_data: (closure callback): data to pass to @callback
+ * @user_data: data to pass to @callback
  *
  * This function shows @self to the user.
  *
